@@ -1,3 +1,4 @@
+#![deny(missing_docs)]
 //! Text Reader for large text file.
 //!
 //! # Example
@@ -5,7 +6,7 @@
 //! ```
 //! use gchemol_parser::TextReader;
 //! 
-//! let mut reader = TextReader::from_path("./tests/files/ch3f.mol2").unwrap();
+//! let mut reader = TextReader::try_from_path("./tests/files/ch3f.mol2".as_ref()).unwrap();
 //! 
 //! // read a line into `s`
 //! let mut s = String::new();
@@ -23,20 +24,24 @@
 //! }
 //! ```
 
-// mods
+// [[file:../parser.note::cbed1309][cbed1309]]
+use gut::prelude::*;
 
-// [[file:~/Workspace/Programming/gchemol-rs/parser/parser.note::*mods][mods:1]]
+use std::path::Path;
+// cbed1309 ends here
+
+// [[file:../parser.note::9b3ecbac][9b3ecbac]]
 mod core;
+mod grep;
 mod reader;
-mod parser;
-// mods:1 ends here
+mod view;
+// 9b3ecbac ends here
 
-// exports
-
-// [[file:~/Workspace/Programming/gchemol-rs/parser/parser.note::*exports][exports:1]]
+// [[file:../parser.note::ff35c905][ff35c905]]
 pub mod parsers;
 pub mod partition;
 pub use crate::reader::*;
 
-pub use crate::parser::TextParser;
-// exports:1 ends here
+pub use crate::grep::GrepReader;
+pub use crate::view::TextViewer;
+// ff35c905 ends here
